@@ -101,7 +101,7 @@ namespace MonoDevelop.Core.AddIns
 			}
 			
 			if (addin == null)
-				throw new ArgumentException ("Application '" + addinId + "' not found.");
+				throw new UserException ("Application '" + addinId + "' not found.");
 			
 			PreloadAddin (null, addin);
 			
@@ -115,6 +115,12 @@ namespace MonoDevelop.Core.AddIns
 			}
 		}
 		
+		public IApplicationInfo[] GetApplications ()
+		{
+			AddInStatus ads = Runtime.SetupService.GetAddInStatus ();
+			return (IApplicationInfo[]) ads.Applications;
+		}
+		
 		public bool IsAddinLoaded (string id)
 		{
 			return AddInTreeSingleton.AddInTree.AddIns [id] != null;
@@ -261,4 +267,11 @@ namespace MonoDevelop.Core.AddIns
 			return AddInTreeSingleton.AddInTree.GetTreeNode (path);
 		}
 	}
+	
+	
+	public interface IApplicationInfo
+	{
+		string Id { get; }
+		string Description { get; }
+	}
 }
