@@ -89,7 +89,7 @@ namespace MonoDevelop.Ide.Gui
 			try {
 				new Gnome.Program (name, version, Gnome.Modules.UI, remainingArgs);
 			} catch (Exception ex) {
-				string msg = GettextCatalog.GetString ("MonoDevelop failed to start.\nIf you installed MonoDevelop using a binary instaler, take a look at \nhttp://www.mono-project.com/InstallerInstructions for more info about possible\ncauses of this error.");
+				string msg = GettextCatalog.GetString ("MonoDevelop failed to start.\nIf you installed MonoDevelop using a binary installer, take a look at \nhttp://www.mono-project.com/InstallerInstructions for more info about possible\ncauses of this error.");
 				Console.WriteLine (new string ('#',70));
 				Console.WriteLine (msg);
 				Console.WriteLine (new string ('#',70));
@@ -256,6 +256,14 @@ namespace MonoDevelop.Ide.Gui
 				if (!File.Exists (path))
 					return true;
 					
+				// Only run the check for SUSE 10
+				StreamReader sr = File.OpenText (path);
+				string txt = sr.ReadToEnd ();
+				sr.Close ();
+				
+				if (txt.IndexOf ("SUSE LINUX 10") == -1)
+					return true;
+					
 				string current_libgda;
 				string current_gnomevfs;
 				string required_libgda = "1.3.91.5.4";
