@@ -47,7 +47,7 @@ namespace MonoDevelop.Projects.Parser
 	{
 		static readonly int MAX_ACTIVE_COUNT = 100;
 		static readonly int MIN_ACTIVE_COUNT = 50;
-		static protected readonly int FORMAT_VERSION = 4;
+		static protected readonly int FORMAT_VERSION = 6;
 		
 		NamespaceEntry rootNamespace;
 		protected ArrayList references;
@@ -183,74 +183,84 @@ namespace MonoDevelop.Projects.Parser
 				BinaryFormatter bf = new BinaryFormatter ();
 				BinaryWriter bw = new BinaryWriter (dfile);
 				
-				// The headers are the first thing to write, so they can be read
-				// without deserializing the whole file.
-				bf.Serialize (dfile, headers);
-				
-				// The position of the index will be written here
-				long indexOffsetPos = dfile.Position;
-				bw.Write ((long)0);
-				
-				MemoryStream buffer = new MemoryStream ();
-				BinaryWriter bufWriter = new BinaryWriter (buffer);
-				
-				// Write all class data
-				foreach (FileEntry fe in files.Values) 
-				{
-					ClassEntry ce = fe.FirstClass;
-					while (ce != null)
-					{
-						IClass c = ce.Class;
-						byte[] data;
-						int len;
-						
-						if (c == null) {
-							// Copy the data from the source file
-							if (datareader == null) {
-								datafile = new FileStream (dataFile, FileMode.Open, FileAccess.Read, FileShare.Read);
-								datareader = new BinaryReader (datafile);
-							}
-							datafile.Position = ce.Position;
-							len = datareader.ReadInt32 ();
-							data = new byte[len];
-							datafile.Read (data, 0, len);
-						}
-						else {
-							buffer.Position = 0;
-							PersistentClass.WriteTo (c, bufWriter, parserDatabase.DefaultNameEncoder);
-							data = buffer.GetBuffer ();
-							len = (int)buffer.Position;
-						}
-						
-						ce.Position = dfile.Position;
-						bw.Write (len);
-						bw.Write (data, 0, len);
-						ce = ce.NextInFile;
-					}
-				}
-				
-				// Write the index
-				long indexOffset = dfile.Position;
-				
-				Queue dataQueue = new Queue ();
-				dataQueue.Enqueue (references);
-				dataQueue.Enqueue (rootNamespace);
-				dataQueue.Enqueue (files);
-				SerializeData (dataQueue);
-				bf.Serialize (dfile, dataQueue.ToArray ());
-				
-				dfile.Position = indexOffsetPos;
-				bw.Write (indexOffset);
-				
-				bw.Close ();
-				dfile.Close ();
-				
-				CloseReader ();
-				
-				if (File.Exists (dataFile))
-					File.Delete (dataFile);
+				try {
+					// The headers are the first thing to write, so they can be read
+					// without deserializing the whole file.
+					bf.Serialize (dfile, headers);
 					
-				File.Move (tmpDataFile, dataFile);
+					// The position of the index will be written here
+					long indexOffsetPos = dfile.Position;
+					bw.Write ((long)0);
+					
+					MemoryStream buffer = new MemoryStream ();
+					BinaryWriter bufWriter = new BinaryWriter (buffer);
+					
+					// Write all class data
+					foreach (FileEntry fe in files.Values) 
+					{
+						ClassEntry ce = fe.FirstClass;
+						while (ce != null)
+						{
+							IClass c = ce.Class;
+							byte[] data;
+							int len;
+							
+							if (c == null) {
+								// Copy the data from the source file
+								if (datareader == null) {
+									datafile = new FileStream (dataFile, FileMode.Open, FileAccess.Read, FileShare.Read);
+									datareader = new BinaryReader (datafile);
+								}
+								datafile.Position = ce.Position;
+								len = datareader.ReadInt32 ();
+								data = new byte[len];
+								datafile.Read (data, 0, len);
+							}
+							else {
+								buffer.Position = 0;
+								PersistentClass.WriteTo (c, bufWriter, parserDatabase.DefaultNameEncoder);
+								data = buffer.GetBuffer ();
+								len = (int)buffer.Position;
+							}
+							
+							ce.Position = dfile.Position;
+							bw.Write (len);
+							bw.Write (data, 0, len);
+							ce = ce.NextInFile;
+						}
+					}
+					
+					bw.Flush ();
+					
+					// Write the index
+					long indexOffset = dfile.Position;
+					
+					Queue dataQueue = new Queue ();
+					dataQueue.Enqueue (references);
+					dataQueue.Enqueue (rootNamespace);
+					dataQueue.Enqueue (files);
+					SerializeData (dataQueue);
+					bf.Serialize (dfile, dataQueue.ToArray ());
+					
+					dfile.Position = indexOffsetPos;
+					bw.Write (indexOffset);
+					
+					bw.Close ();
+					dfile.Close ();
+					dfile = null;
+					
+					CloseReader ();
+					
+					if (File.Exists (dataFile))
+						File.Delete (dataFile);
+						
+					File.Move (tmpDataFile, dataFile);
+				} catch {
+					if (dfile != null)
+						dfile.Close ();
+					if (File.Exists (tmpDataFile))
+						File.Delete (tmpDataFile);
+				}
 			}
 		}
 		
@@ -381,7 +391,7 @@ namespace MonoDevelop.Projects.Parser
 				{
 					if (!File.Exists (file.FileName)) continue;
 					FileInfo fi = new FileInfo (file.FileName);
-					if (fi.LastWriteTime > file.LastParseTime || file.ParseErrorRetries > 0) 
+					if ((fi.LastWriteTime > file.LastParseTime || file.ParseErrorRetries > 0) && !file.DisableParse)
 						QueueParseJob (file);
 				}
 			}
@@ -450,13 +460,14 @@ namespace MonoDevelop.Projects.Parser
 			return false;
 		}
 		
-		public void AddFile (string fileName)
+		public FileEntry AddFile (string fileName)
 		{
 			lock (rwlock)
 			{
 				FileEntry fe = new FileEntry (fileName);
 				files [fileName] = fe;
 				modified = true;
+				return fe;
 			}
 		}
 		
@@ -487,6 +498,8 @@ namespace MonoDevelop.Projects.Parser
 				FileEntry fe = files [fileName] as FileEntry;
 				if (fe == null) return null;
 				
+				// Get the namespace entry for each class
+				
 				bool[] added = new bool [newClasses.Count];
 				NamespaceEntry[] newNss = new NamespaceEntry [newClasses.Count];
 				for (int n=0; n<newClasses.Count; n++) {
@@ -557,7 +570,7 @@ namespace MonoDevelop.Projects.Parser
 			}
 		}
 		
-		public void GetNamespaceContents (ArrayList list, string subNameSpace, bool caseSensitive)
+		public void GetNamespaceContents (LanguageItemCollection list, string subNameSpace, bool caseSensitive)
 		{
 			lock (rwlock)
 			{
@@ -567,7 +580,7 @@ namespace MonoDevelop.Projects.Parser
 				
 				foreach (DictionaryEntry en in tns.Contents) {
 					if (en.Value is NamespaceEntry)
-						list.Add (en.Key);
+						list.Add (new Namespace ((string)en.Key));
 					else
 						list.Add (GetClass ((ClassEntry)en.Value));
 				}
