@@ -59,6 +59,12 @@ namespace MonoDevelop.Projects.Parser
 		public string GenerateAssemblyDatabase (string baseDir, string name)
 		{
 			AssemblyCodeCompletionDatabase db = new AssemblyCodeCompletionDatabase (baseDir, name, (ParserDatabase) CreateParserDatabase());
+			
+			// This exception is needed to inform to the main process that the assembly
+			// could not be found, so it can stop retrying to parse.
+			if (db.LoadError)
+				throw new InvalidOperationException ("Could find assembly: " + name);
+				
 			db.ParseInExternalProcess = false;
 			db.ParseAll ();
 			db.Write ();
@@ -235,7 +241,8 @@ namespace MonoDevelop.Projects.Parser
 					return parser.Resolve (this, expression, caretLineNumber, caretColumn, fileName, fileContent);
 				}
 				return null;
-			} catch {
+			} catch (Exception ex) {
+				Runtime.LoggingService.Error (ex);
 				return null;
 			}
 		}
@@ -248,7 +255,8 @@ namespace MonoDevelop.Projects.Parser
 					return parser.IsAsResolve (this, expression, caretLineNumber, caretColumn, fileName, fileContent);
 				}
 				return null;
-			} catch {
+			} catch (Exception ex) {
+				Runtime.LoggingService.Error (ex);
 				return null;
 			}
 		}
@@ -270,7 +278,8 @@ namespace MonoDevelop.Projects.Parser
 					return parser.ResolveIdentifier (this, id, caretLineNumber, caretColumn, fileName, fileContent);
 				}
 				return null;
-			} catch {
+			} catch (Exception ex) {
+				Runtime.LoggingService.Error (ex);
 				return null;
 			}
 		}
@@ -577,11 +586,14 @@ namespace MonoDevelop.Projects.Parser
 					if (uri.StartsWith ("Assembly:"))
 					{
 						string file = uri.Substring (9);
+						string realUri = uri;
 						
 						// We may be trying to load an assembly db using a partial name.
 						// In this case we get the full name to avoid database conflicts
-						file = AssemblyCodeCompletionDatabase.GetFullAssemblyName (file);
-						string realUri = "Assembly:" + file;
+						string fname = AssemblyCodeCompletionDatabase.GetFullAssemblyName (file);
+						if (fname != null)
+							realUri = "Assembly:" + fname;
+							
 						db = (CodeCompletionDatabase) databases [realUri];
 						if (db != null) {
 							databases [uri] = db;
@@ -813,16 +825,21 @@ namespace MonoDevelop.Projects.Parser
 			CleanUnusedDatabases ();
 		}
 		
+		internal void NotifyReferencesChanged (CodeCompletionDatabase db)
+		{
+			foreach (ReferenceEntry re in db.References) {
+				// Make sure the db is loaded
+				GetDatabase (re.Uri);
+			}
+			CleanUnusedDatabases ();
+		}
+		
 		void OnProjectReferencesChanged (object sender, ProjectReferenceEventArgs args)
 		{
 			ProjectCodeCompletionDatabase db = GetProjectDatabase (args.Project);
 			if (db != null) {
 				db.UpdateFromProject ();
-				foreach (ReferenceEntry re in db.References)
-				{
-					// Make sure the db is loaded
-					GetDatabase (re.Uri);
-				}
+				NotifyReferencesChanged (db);
 			}
 		}
 		
@@ -1008,8 +1025,10 @@ namespace MonoDevelop.Projects.Parser
 					
 					if (project != null) {
 						ProjectCodeCompletionDatabase db = GetProjectDatabase (project);
-						ClassUpdateInformation res = db.UpdateFromParseInfo (parseInformation, fileName);
-						if (res != null) NotifyParseInfoChange (fileName, res, project);
+						if (db != null) {
+							ClassUpdateInformation res = db.UpdateFromParseInfo (parseInformation, fileName);
+							if (res != null) NotifyParseInfoChange (fileName, res, project);
+						}
 					}
 					else {
 						SimpleCodeCompletionDatabase db = GetSingleFileDatabase (fileName);
@@ -1238,7 +1257,7 @@ namespace MonoDevelop.Projects.Parser
 				string aliasString = entry.Key.ToString();
 				if (caseSensitive ? partitialNamespaceName.StartsWith(aliasString) : partitialNamespaceName.ToLower().StartsWith(aliasString.ToLower())) {
 					if (aliasString.Length >= 0) {
-						string nsName = nsName = String.Concat(entry.Value.ToString(), partitialNamespaceName.Remove(0, aliasString.Length));
+						string nsName = String.Concat(entry.Value.ToString(), partitialNamespaceName.Remove(0, aliasString.Length));
 						if (NamespaceExists (db, nsName, caseSensitive)) {
 							return nsName;
 						}
