@@ -10,20 +10,14 @@ using MonoDevelop.Core;
 using System;
 using System.Collections;
 using System.Xml;
-using System.Reflection;
 using System.Collections.Specialized;
+using Mono.Cecil;
 
 namespace MonoDevelop.Projects.Parser
 {
 	[Serializable]
 	internal class ReflectionClass : AbstractClass
 	{
-		BindingFlags flags = BindingFlags.Instance  | 
-		                     BindingFlags.Static    | 
-//		                     BindingFlags.DeclaredOnly |
-		                     BindingFlags.NonPublic |
-		                     BindingFlags.Public;
-		
 		/// <value>
 		/// A reflection class doesn't have a compilation unit (because
 		/// it is not parsed the information is gathered using reflection)
@@ -34,19 +28,26 @@ namespace MonoDevelop.Projects.Parser
 			}
 		}
 		
-		public static bool IsDelegate(Type type)
+		public static bool IsDelegate (TypeReference type)
 		{
-			return type.IsSubclassOf(typeof(Delegate)) && type != typeof(MulticastDelegate);
+			if (type.FullName == "System.MulticastDelegate" || type.FullName == "System.Delegate")
+				return false;
+
+			while (type != null) {
+				if (type.FullName == "System.Delegate")
+					return true;
+				TypeDefinition td = type as TypeDefinition;
+				if (td != null)
+					type = td.BaseType;
+				else
+					break;
+			}
+			return false;
 		}
 		
-		public ReflectionClass(Type type)
+		public ReflectionClass(TypeDefinition type)
 		{
-
-			if (type == null)
-				type = Type.GetType ("System.Object");
-			
-
-			FullyQualifiedName = type.FullName;
+			FullyQualifiedName = type.FullName.Replace ('/','+');
 
 			XmlDocument docs = Services.DocumentationService != null ? Services.DocumentationService.GetHelpXml (FullyQualifiedName) : null;
 			if (docs != null) {
@@ -56,12 +57,12 @@ namespace MonoDevelop.Projects.Parser
 				}
 			}
 			
-			FullyQualifiedName = FullyQualifiedName.Replace("+", ".");
+			FullyQualifiedName = FullyQualifiedName.Replace('+', '.');
 			
 			// set classtype
 			if (IsDelegate(type)) {
 				classType = ClassType.Delegate;
-				MethodInfo invoke          = type.GetMethod("Invoke");
+				MethodDefinition invoke = type.Methods.GetMethod ("Invoke")[0];
 				ReflectionMethod newMethod = new ReflectionMethod(invoke, null);
 				methods.Add(newMethod);
 			} else if (type.IsInterface) {
@@ -76,10 +77,6 @@ namespace MonoDevelop.Projects.Parser
 			
 			modifiers = ModifierEnum.None;
 			
-			if (type.IsNestedAssembly) {
-				modifiers |= ModifierEnum.Internal;
-			}
-			
 			if (type.IsSealed) {
 				modifiers |= ModifierEnum.Sealed;
 			}
@@ -87,20 +84,7 @@ namespace MonoDevelop.Projects.Parser
 				modifiers |= ModifierEnum.Abstract;
 			}
 			
-			if (type.IsNestedPrivate ) { // I assume that private is used most and public last (at least should be)
-				modifiers |= ModifierEnum.Private;
-			} else if (type.IsNestedFamily ) {
-				modifiers |= ModifierEnum.Protected;
-			} else if (type.IsNestedPublic || type.IsPublic) {
-				modifiers |= ModifierEnum.Public;
-			} else if (type.IsNotPublic) {
-				modifiers |= ModifierEnum.Internal;
-			} else if (type.IsNestedFamORAssem) {
-				modifiers |= ModifierEnum.ProtectedOrInternal;
-			} else if (type.IsNestedFamANDAssem) {
-				modifiers |= ModifierEnum.Protected;
-				modifiers |= ModifierEnum.Internal;
-			}
+			modifiers |= GetModifiers (type.Attributes);
 			
 			// set base classes
 			if (type.BaseType != null) { // it's null for System.Object ONLY !!!
@@ -109,15 +93,15 @@ namespace MonoDevelop.Projects.Parser
 			
 			if (classType != ClassType.Delegate) {
 				// add members
-				foreach (Type iface in type.GetInterfaces()) {
+				foreach (TypeReference iface in type.Interfaces) {
 					baseTypes.Add(iface.FullName);
 				}
 				
-				foreach (Type nestedType in type.GetNestedTypes(flags)) {
-					innerClasses.Add(new ReflectionClass(nestedType));
+				foreach (TypeDefinition nestedType in type.NestedTypes) {
+					innerClasses.Add (new ReflectionClass(nestedType));
 				}
 				
-				foreach (FieldInfo field in type.GetFields(flags)) {
+				foreach (FieldDefinition field in type.Fields) {
 //					if (!field.IsSpecialName) {
 					IField newField = new ReflectionField(field, docs);
 					if (!newField.IsInternal) {
@@ -126,15 +110,11 @@ namespace MonoDevelop.Projects.Parser
 //					}
 				}
 				
-				foreach (PropertyInfo propertyInfo in type.GetProperties(flags)) {
+				foreach (PropertyDefinition propertyInfo in type.Properties) {
 //					if (!propertyInfo.IsSpecialName) {
-					ParameterInfo[] p = null;
+					ParameterDefinitionCollection p = propertyInfo.Parameters;
 					
-					// we may not get the permission to access the index parameters
-					try {
-						p = propertyInfo.GetIndexParameters();
-					} catch (Exception) {}
-					if (p == null || p.Length == 0) {
+					if (p == null || p.Count == 0) {
 						IProperty newProperty = new ReflectionProperty(propertyInfo, docs);
 						if (!newProperty.IsInternal) {
 							properties.Add(newProperty);
@@ -148,7 +128,7 @@ namespace MonoDevelop.Projects.Parser
 //					}
 				}
 				
-				foreach (MethodInfo methodInfo in type.GetMethods(flags)) {
+				foreach (MethodDefinition methodInfo in type.Methods) {
 					if (!methodInfo.IsSpecialName) {
 						IMethod newMethod = new ReflectionMethod(methodInfo, docs);
 						
@@ -158,14 +138,14 @@ namespace MonoDevelop.Projects.Parser
 					}
 				}
 				
-				foreach (ConstructorInfo constructorInfo in type.GetConstructors(flags)) {
+				foreach (MethodDefinition constructorInfo in type.Constructors) {
 					IMethod newMethod = new ReflectionMethod(constructorInfo, docs);
 					if (!newMethod.IsInternal) {
 						methods.Add(newMethod);
 					}
 				}
 				
-				foreach (EventInfo eventInfo in type.GetEvents(flags)) {
+				foreach (EventDefinition eventInfo in type.Events) {
 //					if (!eventInfo.IsSpecialName) {
 					IEvent newEvent = new ReflectionEvent(eventInfo, docs);
 					
@@ -176,5 +156,27 @@ namespace MonoDevelop.Projects.Parser
 				}
 			}
 		}
+		
+		public static ModifierEnum GetModifiers (TypeAttributes attributes)
+		{
+			TypeAttributes visibility = attributes & TypeAttributes.VisibilityMask;
+			
+			if (visibility == TypeAttributes.NestedPrivate) { // I assume that private is used most and public last (at least should be)
+				return ModifierEnum.Private;
+			} else if (visibility == TypeAttributes.NestedFamily) {
+				return ModifierEnum.Protected;
+			} else if (visibility == TypeAttributes.NestedPublic || visibility == TypeAttributes.Public) {
+				return ModifierEnum.Public;
+			} else if (visibility == TypeAttributes.NestedAssembly) {
+				return ModifierEnum.Internal;
+			} else if (visibility == TypeAttributes.NotPublic) {
+				return ModifierEnum.Internal;
+			} else if (visibility == TypeAttributes.NestedFamORAssem) {
+				return ModifierEnum.ProtectedOrInternal;
+			} else if (visibility == TypeAttributes.NestedFamANDAssem) {
+				return ModifierEnum.Protected | ModifierEnum.Internal;
+			}
+			return ModifierEnum.None;
+		}
 	}
 }
