@@ -19,6 +19,7 @@ namespace MonoDevelop.Projects
 	public class ProjectCreateInformation
 	{
 		string projectName;
+		string combineName;
 		string combinePath;
 		string projectBasePath;
 		
@@ -31,6 +32,15 @@ namespace MonoDevelop.Projects
 			}
 		}
 		
+		public string CombineName {
+			get {
+				return combineName;
+			}
+			set {
+				combineName = value;
+			}
+		}
+		
 		public string BinPath {
 			get {
 				return combinePath + Path.DirectorySeparatorChar + "bin";
