@@ -47,7 +47,7 @@ namespace CSharpBinding.Parser
 		{
 			// Get line start:
 			int lineStart = offset;
-			while (--lineStart > 0 && txt[lineStart] != '\n');
+			while (--lineStart > 0 && txt[lineStart] != '\n') { }
 			
 			bool inAttribute = false;
 			int parens = 0;
